@@ -5,8 +5,9 @@ Misc. useful functions that can be used at many places in the program.
 import subprocess as sp
 import sys
 
+
 def sys_write_flush(s):
-    """ writes and flushes witout delay a text in the console """
+    """ writes and flushes without delay a text in the console """
     sys.stdout.write(s)
     sys.stdout.flush()
 
